@@ -2,7 +2,7 @@
  *  kaevent.h  -  represents KAlarm calendar events
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -268,13 +268,31 @@ public:
         LIMIT_REMINDER     //!< a reminder
     };
 
-    /** Alarm trigger type. */
+    /** Next trigger type for an alarm. */
     enum TriggerType {
-        ALL_TRIGGER,       //!< next trigger, including reminders, ignoring working hours & holidays
-        MAIN_TRIGGER,      //!< next trigger, excluding reminders, ignoring working hours & holidays
-        WORK_TRIGGER,      //!< next main working time trigger, excluding reminders
-        ALL_WORK_TRIGGER,  //!< next actual working time trigger, including reminders
-        DISPLAY_TRIGGER    //!< next trigger time for display purposes (i.e. excluding reminders)
+
+        /** Next trigger, including reminders. No account is taken of any
+         *  working hours or holiday restrictions when evaluating this. */
+        ALL_TRIGGER,
+
+        /** Next trigger of the main alarm, i.e. excluding reminders. No
+         *  account is taken of any working hours or holiday restrictions when
+         *  evaluating this. */
+        MAIN_TRIGGER,
+
+        /** Next trigger of the main alarm, i.e. excluding reminders, taking
+         *  account of any working hours or holiday restrictions. If the event
+         *  has no working hours or holiday restrictions, this is equivalent to
+         *  MAIN_TRIGGER. */
+        WORK_TRIGGER,
+
+        /** Next trigger, including reminders, taking account of any working
+         *  hours or holiday restrictions. If the event has no working hours or
+         *  holiday restrictions, this is equivalent to ALL_TRIGGER. */
+        ALL_WORK_TRIGGER,
+
+        /** Next trigger time for display purposes (i.e. excluding reminders). */
+        DISPLAY_TRIGGER
     };
 
     /** Command execution error type for last time the alarm was triggered. */
@@ -604,6 +622,9 @@ public:
      */
     Akonadi::Item::Id akonadiItemId() const;
 
+    /** Set the alarm's name. */
+    void setName(const QString& newName);
+
     /** Return the alarm's name. */
     QString name() const;
 
@@ -928,6 +949,9 @@ public:
     /** Return the start time for the event. If the event recurs, this is the
      *  time of the first recurrence. If the event is date-only, this returns a
      *  date-only value.
+     *  @note No account is taken of any working hours or holiday restrictions.
+     *        when determining the start date/time.
+     *
      *  @see mainDateTime()
      */
     DateTime startDateTime() const;
@@ -939,17 +963,26 @@ public:
     void setTime(const KADateTime &dt);
 
     /** Return the next time the main alarm will trigger.
+     *  @note No account is taken of any working hours or holiday restrictions.
+     *        when determining the next trigger date/time.
+     *
      *  @param withRepeats  true to include sub-repetitions, false to exclude them.
      *  @see mainTime(), startDateTime(), setTime()
      */
     DateTime mainDateTime(bool withRepeats = false) const;
 
     /** Return the time at which the main alarm will next trigger.
-     *  Sub-repetitions are ignored. */
+     *  Sub-repetitions are ignored.
+     *  @note No account is taken of any working hours or holiday restrictions.
+     *        when determining the next trigger time.
+     */
     QTime mainTime() const;
 
-    /** Return the time at which the last sub-repetition of the main
-     *  alarm will occur.
+    /** Return the time at which the last sub-repetition of the current
+     *  recurrence of the main alarm will occur.
+     *  @note No account is taken of any working hours or holiday restrictions
+     *        when determining the last sub-repetition time.
+     *
      *  @return last sub-repetition time, or main alarm time if no
      *          sub-repetitions are configured.
      */
@@ -1037,14 +1070,28 @@ public:
     bool workTimeOnly() const;
 
     /** Check whether a date/time is during working hours and/or holidays, depending
-     *  on the flags set for the specified event. */
-    bool isWorkingTime(const KADateTime &dt) const;
+     *  on the flags set for the specified event.
+     *  @deprecated Use !excludedByWorkTimeOrHoliday() instead.
+     */
+    KALARMCAL_DEPRECATED bool isWorkingTime(const KADateTime &dt) const;
+
+    /** Check whether a date/time conflicts with working hours and/or holiday
+     *  restrictions for the alarm.
+     *  @return true if the alarm is disabled from occurring at time @p dt
+     *               because @p dt is outside working hours (if the alarm is
+     *               working time only) or is during a holiday (if the alarm is
+     *               disabled on holidays);
+     *         false if the alarm is permitted to occur at time @p dt. (But
+     *               note that no check is made as to whether the alarm is
+     *               actually scheduled to occur at time @p dt.)
+     */
+    bool excludedByWorkTimeOrHoliday(const KADateTime &dt) const;
 
     /** Set working days and times, to be used by all KAEvent instances.
      *  @param days   bits set to 1 for each working day. Array element 0 = Monday ... 6 = Sunday.
      *  @param start  start time in working day.
      *  @param end    end time in working day.
-     *  @see setWorkTimeOnly(), isWorkingTime()
+     *  @see setWorkTimeOnly(), excludedByWorkTimeOrHoliday()
      */
     static void setWorkTime(const QBitArray &days, const QTime &start, const QTime &end);
 
@@ -1174,6 +1221,8 @@ public:
     int recurInterval() const;
 
     /** Return the longest interval which can occur between consecutive recurrences.
+     *  @note No account is taken of any working hours or holiday restrictions
+     *        when evaluating consecutive recurrence dates/times.
      *  @see recurInterval()
      */
     KCalendarCore::Duration longestRecurrenceInterval() const;
@@ -1181,6 +1230,8 @@ public:
     /** Adjust the event date/time to the first recurrence of the event, on or after
      *  the event start date/time. The event start date may not be a recurrence date,
      *  in which case a later date will be set.
+     *  @note No account is taken of any working hours or holiday restrictions
+     *        when determining the first recurrence of the event.
      */
     void setFirstRecurrence();
 
@@ -1201,6 +1252,9 @@ public:
     Repetition repetition() const;
 
     /** Return the count of the next sub-repetition which is due.
+     *  @note No account is taken of any working hours or holiday restrictions
+     *        when determining the next event sub-repetition.
+     *
      *  @return sub-repetition count (>=1), or 0 for the main recurrence.
      *  @see nextOccurrence()
      */
@@ -1209,7 +1263,11 @@ public:
     /** Return the repetition interval as text suitable for display. */
     QString repetitionText(bool brief = false) const;
 
-    /** Determine whether the event will occur after the specified date/time.
+    /** Determine whether the event will occur strictly after the specified
+     *  date/time. Reminders are ignored.
+     *  @note No account is taken of any working hours or holiday restrictions
+     *        when determining event occurrences.
+     *
      *  @param preDateTime        the specified date/time.
      *  @param includeRepetitions if true and the alarm has a sub-repetition, the
      *                            method will return true if any sub-repetitions
@@ -1224,12 +1282,18 @@ public:
      *  If the alarm has a sub-repetition, and a sub-repetition of a previous
      *  recurrence occurs after the specified date/time, that sub-repetition is
      *  set as the next occurrence.
+     *  @note No account is taken of any working hours or holiday restrictions
+     *        when determining and setting the next occurrence date/time.
+     *
      *  @see nextOccurrence()
      */
     OccurType setNextOccurrence(const KADateTime &preDateTime);
 
-    /** Get the date/time of the next occurrence of the event, after the specified
-     *  date/time.
+    /** Get the date/time of the next occurrence of the event, strictly after
+     *  the specified date/time. Reminders are ignored.
+     *  @note No account is taken of any working hours or holiday restrictions
+     *        when determining the next event occurrence.
+     *
      *  @param preDateTime the specified date/time.
      *  @param result      date/time of next occurrence, or invalid date/time if none.
      *  @param option      how/whether to make allowance for sub-repetitions.
@@ -1237,8 +1301,11 @@ public:
      */
     OccurType nextOccurrence(const KADateTime &preDateTime, DateTime &result, OccurOption option = IGNORE_REPETITION) const;
 
-    /** Get the date/time of the last previous occurrence of the event, before the
-     *  specified date/time.
+    /** Get the date/time of the last previous occurrence of the event,
+     *  strictly before the specified date/time. Reminders are ignored.
+     *  @note No account is taken of any working hours or holiday restrictions
+     *        when determining the previous event occurrence.
+     *
      *  @param afterDateTime       the specified date/time.
      *  @param result              date/time of previous occurrence, or invalid
      *                             date/time if none.
